==> jc-1.4.0.tar.gz: java/util/prefs/BackingStoreException.h <==
// public class java.util.prefs.BackingStoreException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 219adc8871c34989 java_util_prefs_BackingStoreException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_util_prefs_BackingStoreException_H_
#define _JC_java_util_prefs_BackingStoreException_H_

// Forward structure declarations
struct _jc_java_io_ObjectInputStream$object;
struct _jc_java_io_ObjectOutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_java_util_prefs_BackingStoreException$sub_refs	_jc_java_util_prefs_BackingStoreException$sub_refs;
typedef struct _jc_java_util_prefs_BackingStoreException$sub_nonrefs	_jc_java_util_prefs_BackingStoreException$sub_nonrefs;
typedef struct _jc_java_util_prefs_BackingStoreException$refs	_jc_java_util_prefs_BackingStoreException$refs;
typedef struct _jc_java_util_prefs_BackingStoreException$nonrefs	_jc_java_util_prefs_BackingStoreException$nonrefs;
typedef struct _jc_java_util_prefs_BackingStoreException$object	_jc_java_util_prefs_BackingStoreException$object;

typedef struct _jc_java_util_prefs_BackingStoreException$fields_struct	_jc_java_util_prefs_BackingStoreException$fields_struct;
typedef const struct _jc_java_util_prefs_BackingStoreException$vmethods	_jc_java_util_prefs_BackingStoreException$vmethods;
typedef const struct _jc_java_util_prefs_BackingStoreException$vtable	_jc_java_util_prefs_BackingStoreException$vtable;
typedef const struct _jc_java_util_prefs_BackingStoreException$vtype	_jc_java_util_prefs_BackingStoreException$vtype;

// Class fields structure
struct _jc_java_util_prefs_BackingStoreException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_prefs_BackingStoreException$fields_struct _jc_java_util_prefs_BackingStoreException$class_fields;

// Constructors
extern void _jc_java_util_prefs_BackingStoreException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_util_prefs_BackingStoreException$object *, struct _jc_java_lang_String$object *);
extern void _jc_java_util_prefs_BackingStoreException$method$_init$8b52a141d2a0e2bc(_jc_env *, struct _jc_java_util_prefs_BackingStoreException$object *, struct _jc_java_lang_Throwable$object *);

// Virtual methods
extern void _jc_java_util_prefs_BackingStoreException$method$readObject$a94c095c21a0b9e8(_jc_env *, struct _jc_java_util_prefs_BackingStoreException$object *, struct _jc_java_io_ObjectInputStream$object *);
extern void _jc_java_util_prefs_BackingStoreException$method$writeObject$6755db4c37bbfbcf(_jc_env *, struct _jc_java_util_prefs_BackingStoreException$object *, struct _jc_java_io_ObjectOutputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_prefs_BackingStoreException$method_info$readObject$a94c095c21a0b9e8;
extern _jc_method _jc_java_util_prefs_BackingStoreException$method_info$writeObject$6755db4c37bbfbcf;

// Virtual methods structure
struct _jc_java_util_prefs_BackingStoreException$vmethods {
	void	(*readObject$a94c095c21a0b9e8)(_jc_env *, struct _jc_java_util_prefs_BackingStoreException$object *, struct _jc_java_io_ObjectInputStream$object *);
	void	(*writeObject$6755db4c37bbfbcf)(_jc_env *, struct _jc_java_util_prefs_BackingStoreException$object *, struct _jc_java_io_ObjectOutputStream$object *);
};

// Vtable
struct _jc_java_util_prefs_BackingStoreException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_util_prefs_BackingStoreException$vmethods	java_util_prefs_BackingStoreException;
};

// Vtype
struct _jc_java_util_prefs_BackingStoreException$vtype {
	_jc_type			type;
	_jc_java_util_prefs_BackingStoreException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_prefs_BackingStoreException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_prefs_BackingStoreException$refs {
    _jc_java_util_prefs_BackingStoreException$sub_refs	java_util_prefs_BackingStoreException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_prefs_BackingStoreException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_prefs_BackingStoreException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_util_prefs_BackingStoreException$sub_nonrefs	java_util_prefs_BackingStoreException;
};

// Object instance structure
struct _jc_java_util_prefs_BackingStoreException$object {
	_jc_java_util_prefs_BackingStoreException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_prefs_BackingStoreException$vtype	*vtype;
	_jc_java_util_prefs_BackingStoreException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_prefs_BackingStoreException$vtype _jc_java_util_prefs_BackingStoreException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_prefs_BackingStoreException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_prefs_BackingStoreException$class_object;

#endif	/* _JC_java_util_prefs_BackingStoreException_H_ */

==> jc-1.4.6.tar.gz: java/util/prefs/BackingStoreException.h <==
// public class java.util.prefs.BackingStoreException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 219adc8871c34989 java_util_prefs_BackingStoreException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_util_prefs_BackingStoreException_H_
#define _JC_java_util_prefs_BackingStoreException_H_

// Forward structure declarations
struct _jc_java_io_ObjectInputStream$object;
struct _jc_java_io_ObjectOutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_java_util_prefs_BackingStoreException$sub_refs	_jc_java_util_prefs_BackingStoreException$sub_refs;
typedef struct _jc_java_util_prefs_BackingStoreException$sub_nonrefs	_jc_java_util_prefs_BackingStoreException$sub_nonrefs;
typedef struct _jc_java_util_prefs_BackingStoreException$refs	_jc_java_util_prefs_BackingStoreException$refs;
typedef struct _jc_java_util_prefs_BackingStoreException$nonrefs	_jc_java_util_prefs_BackingStoreException$nonrefs;
typedef struct _jc_java_util_prefs_BackingStoreException$object	_jc_java_util_prefs_BackingStoreException$object;

typedef struct _jc_java_util_prefs_BackingStoreException$fields_struct	_jc_java_util_prefs_BackingStoreException$fields_struct;
typedef const struct _jc_java_util_prefs_BackingStoreException$vmethods	_jc_java_util_prefs_BackingStoreException$vmethods;
typedef const struct _jc_java_util_prefs_BackingStoreException$vtable	_jc_java_util_prefs_BackingStoreException$vtable;
typedef const struct _jc_java_util_prefs_BackingStoreException$vtype	_jc_java_util_prefs_BackingStoreException$vtype;

// Class fields structure
struct _jc_java_util_prefs_BackingStoreException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_prefs_BackingStoreException$fields_struct _jc_java_util_prefs_BackingStoreException$class_fields;

// Constructors
extern void _jc_java_util_prefs_BackingStoreException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_util_prefs_BackingStoreException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_prefs_BackingStoreException$method$_init$8b52a141d2a0e2bc(_jc_env *, struct _jc_java_util_prefs_BackingStoreException$object *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_util_prefs_BackingStoreException$method$readObject$a94c095c21a0b9e8(_jc_env *, struct _jc_java_util_prefs_BackingStoreException$object *, struct _jc_java_io_ObjectInputStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_prefs_BackingStoreException$method$writeObject$6755db4c37bbfbcf(_jc_env *, struct _jc_java_util_prefs_BackingStoreException$object *, struct _jc_java_io_ObjectOutputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_prefs_BackingStoreException$method_info$readObject$a94c095c21a0b9e8;
extern _jc_method _jc_java_util_prefs_BackingStoreException$method_info$writeObject$6755db4c37bbfbcf;

// Virtual methods structure
struct _jc_java_util_prefs_BackingStoreException$vmethods {
	void	(*readObject$a94c095c21a0b9e8)(_jc_env *, struct _jc_java_util_prefs_BackingStoreException$object *, struct _jc_java_io_ObjectInputStream$object *) _JC_JCNI_ATTR;
	void	(*writeObject$6755db4c37bbfbcf)(_jc_env *, struct _jc_java_util_prefs_BackingStoreException$object *, struct _jc_java_io_ObjectOutputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_prefs_BackingStoreException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_util_prefs_BackingStoreException$vmethods	java_util_prefs_BackingStoreException;
};

// Vtype
struct _jc_java_util_prefs_BackingStoreException$vtype {
	_jc_type			type;
	_jc_java_util_prefs_BackingStoreException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_prefs_BackingStoreException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_prefs_BackingStoreException$refs {
    _jc_java_util_prefs_BackingStoreException$sub_refs	java_util_prefs_BackingStoreException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_prefs_BackingStoreException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_prefs_BackingStoreException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_util_prefs_BackingStoreException$sub_nonrefs	java_util_prefs_BackingStoreException;
};

// Object instance structure
struct _jc_java_util_prefs_BackingStoreException$object {
	_jc_java_util_prefs_BackingStoreException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_prefs_BackingStoreException$vtype	*vtype;
	_jc_java_util_prefs_BackingStoreException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_prefs_BackingStoreException$vtype _jc_java_util_prefs_BackingStoreException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_prefs_BackingStoreException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_prefs_BackingStoreException$class_object;

#endif	/* _JC_java_util_prefs_BackingStoreException_H_ */
